@@ -21,6 +21,7 @@ from fastapi import (
 )
 from fastapi.security import OAuth2PasswordBearer, OAuth2PasswordRequestForm
 from jose import ExpiredSignatureError, JWTError, jwt
+from jose.constants import ALGORITHMS
 from passlib.context import CryptContext
 from pydantic import BaseModel
 import re
@@ -75,27 +76,34 @@ class Authenticator(ABC):
     Parameters
     ----------
     key: ``str``
-         The cryptographically strong signing key for JWTs.
+        The cryptographically strong signing key for JWTs. If using
+        certificates, provide the private key in the form of a string of its
+        contents.
     algorithm: ``str``
-               The algorithm to use to sign JWTs. Defaults
-               to HS256.
+        The algorithm to use to sign JWTs. Defaults
+        to `jose.constants.ALGORITHMS.HS256`. If you are using public-private keys,
+        use `jose.constants.ALGORITHMS.RS256`
     cookie_name: ``str``
-                 The name of the cookie to set in the
-                 browser. Defaults to the value of
-                 ``fastapi_token``.
+        The name of the cookie to set in the
+        browser. Defaults to the value of
+        ``fastapi_token``.
     path: ``str``
-          The path that authentication requests will go to.
-          Defaults to "token".
+        The path that authentication requests will go to.
+        Defaults to "token".
+    public_key:
+        If using certificates, provide the public key in the form of a string
+        of its contents.
     """
 
     def __init__(
         self,
         key: str,
         /,
-        algorithm: str = "HS256",
+        algorithm: str = ALGORITHMS.HS256,
         cookie_name: str = "fastapi_token",
         path: str = "token",
         exp: timedelta = timedelta(hours=1),
+        public_key=None,
     ):
         self.cookie_name = cookie_name or self.COOKIE_NAME
         self.key = key
@@ -105,6 +113,7 @@ class Authenticator(ABC):
         self._router = None
         self.pwd_context = CryptContext(schemes=["bcrypt"], deprecated="auto")
         self.exp = exp
+        self.public_key = public_key
 
         async def _try_jwt(
             self,
@@ -118,7 +127,11 @@ class Authenticator(ABC):
             if not token and cookie_token:
                 token = cookie_token
             try:
-                payload = jwt.decode(token, key, algorithms=[algorithm])
+                if public_key:
+                    decode_key = public_key
+                else:
+                    decode_key = key
+                payload = jwt.decode(token, decode_key, algorithms=[algorithm])
                 if "jti" in payload:
                     jti = payload["jti"]
                     is_valid = await self.validate_jti(jti, session_getter)
@@ -140,11 +153,7 @@ class Authenticator(ABC):
             _try_jwt.__get__(self, self.__class__),
         )
 
-
-        async def try_account_data(
-            self,
-            token: dict = Depends(self._try_jwt)
-        ):
+        async def try_account_data(self, token: dict = Depends(self._try_jwt)):
             if token and "account" in token:
                 return token["account"]
             return None
@@ -201,7 +210,7 @@ class Authenticator(ABC):
             request: Request,
             response: Response,
             session_getter=Depends(self.get_session_getter),
-            jwt: dict = Depends(self._try_jwt)
+            jwt: dict = Depends(self._try_jwt),
         ) -> Token:
             return await Authenticator.logout(
                 self,
